Loads a recipe written by save_recipe(). Validates that the file
contains a masque_recipe and informs (does not error) if the recipe
was written by a different package version than the one currently
installed.
Loads a recipe written by save_recipe(). Validates that the file
contains a masque_recipe and informs (does not error) if the recipe
was written by a different package version than the one currently
installed.